from setuptools import setup

setup(name="ga_bi_distribution_classes",
      version="0.1",
      description="Gaussian and Binomial distribution classes",
      packages=["ga_bi_distribution_classes"],
      zip_safe=False)
